@@ -4,11 +4,6 @@
 # Verify current version before use at: https://github.com/MAVENSDC/PyTplot
 
 from _collections import OrderedDict
-bokeh_available = True
-try:
-    from . import HTMLPlotter
-except ImportError:
-    bokeh_available = False
 
 import os
 import sys
@@ -114,7 +109,7 @@ static_tavg_window = None  # 2D window showing averaged y and z data for a speci
 tplot_opt_glob = dict(tools="xpan,crosshair,reset",
                       min_border_top=12, min_border_bottom=12,
                       title_align='center', window_size=[800, 800],
-                      title_size='12pt', title_text='', crosshair=True,
+                      title_size='12', title_text='', crosshair=True,
                       data_gap=0, black_background=False, axis_font_size=12, axis_tick_num=[(0, 1000000000), (3, 1),],
                       y_axis_zoom=False)
 lim_info = {}
@@ -130,12 +125,6 @@ if using_graphics:
                    'qtTVarFigureAlt': QtPlotter.TVarFigureAlt,
                    'qtTVarFigureMap': QtPlotter.TVarFigureMap}
 
-if bokeh_available:
-    bokeh_plotters = {'bkTVarFigure1D': HTMLPlotter.TVarFigure1D,
-                      'bkTVarFigureMap': HTMLPlotter.TVarFigureMap,
-                      'bkTVarFigureAlt': HTMLPlotter.TVarFigureAlt,
-                      'bkTVarFigureSpec': HTMLPlotter.TVarFigureSpec}
-
 from .store_data import store_data, store
 from .tplot import tplot
 from .get_data import get_data, get
@@ -147,27 +136,38 @@ from pytplot.exporters.tplot_save import tplot_save
 from .tplot_names import tplot_names
 from .tnames import tnames
 from pytplot.importers.tplot_restore import tplot_restore
+from .is_pseudovariable import is_pseudovariable
+from .count_traces import count_traces
 from .get_timespan import get_timespan
 from .tplot_options import tplot_options
 from .tplot_rename import tplot_rename
 from .tplot_copy import tplot_copy
 from .replace_data import replace_data
+from .replace_metadata import replace_metadata
 from .get_ylimits import get_ylimits
 from .timebar import timebar
+from .databar import databar
 from .del_data import del_data
 from .timespan import timespan
 from .options import options
 from .timestamp import timestamp
-from .time_double import time_float,time_double
-from .time_string import time_string, time_datetime
+from .time_double import time_float,time_double, time_float_one
+from .time_string import time_string, time_datetime, time_string_one
 from pytplot.importers.cdf_to_tplot import cdf_to_tplot
 from pytplot.importers.netcdf_to_tplot import netcdf_to_tplot
 from pytplot.importers.sts_to_tplot import sts_to_tplot
 from .tplot_utilities import compare_versions
 from .tplot_utilities import highlight
 from .tplot_utilities import annotate
+from .data_att_getters_setters import set_coords, get_coords, set_units, get_units
+from .data_exists import data_exists
 from .link import link
-from pytplot.tplot_math import *
+from .tres import tres
+from .format_sandbox import format_sandbox
+from .tplot_math import *
+from .wildcard_routines import wildcard_expand, tplot_wildcard_expand, tname_byindex, tindex_byname
+from .MPLPlotter.tplot_vl import tplot_vl
+from .MPLPlotter.ctime import ctime
 
 # set up logging/console output
 import logging
