@@ -7,32 +7,42 @@ import pytplot
 from . import tplot_utilities
 import logging
 
-def get_timespan(name):
+def get_timespan(name=None):
     """
-    This function extracts the time span from the Tplot Variables stored in memory.  
+    This function extracts the time span from the Tplot Variables stored in memory.
+    If called with no arguments, return the global timespan set by timespan(), or None if none has been set.
     
-    Parameters:
+    Parameters
+    ----------
         name : str 
             Name of the tplot variable
          
-    Returns:
+    Returns
+    -------
+    list of float
         time_begin : float
             The beginning of the time series
         time_end : float
             The end of the time series
             
-    Examples:
+    Examples
+    --------
         >>> # Retrieve the time span from Variable 1
-        >>> import pytplot
+        >>> import pyspedas
         >>> x_data = [1,2,3,4,5]
         >>> y_data = [1,2,3,4,5]
-        >>> pytplot.store_data("Variable1", data={'x':x_data, 'y':y_data})
-        >>> time1, time2 = pytplot.get_timespan("Variable1")
+        >>> pyspedas.store_data("Variable1", data={'x':x_data, 'y':y_data})
+        >>> time1, time2 = pyspedas.get_timespan("Variable1")
 
     """
-    
-    if name not in pytplot.data_quants.keys():
+
+    if name is None:
+        if 'x_range' in pytplot.tplot_opt_glob.keys():
+            return pytplot.tplot_opt_glob['x_range']
+        else:
+            return None
+    elif name not in pytplot.data_quants.keys():
         logging.info("The name %s is currently not in pytplot",name)
-        return
+        return None
 
     return pytplot.data_quants[name].attrs['plot_options']['trange'][0], pytplot.data_quants[name].attrs['plot_options']['trange'][1]
\ No newline at end of file
