@@ -12,16 +12,19 @@ def timestamp(val):
     This function will turn on a time stamp that shows up at the bottom of every generated plot.
 
     Parameters
+    ----------
         val  str
             A string that can either be 'on' or 'off'.
 
     Returns
+    -------
         None
 
     Examples
-         # Turn on the timestamp
-         import pytplot
-         pytplot.timestamp('on')
+    --------
+         >>> # Turn on the timestamp
+         >>> import pyspedas
+         >>> pyspedas.timestamp('on')
     """
 
     if val == 'on':
