@@ -10,23 +10,35 @@ from .xlim import xlim
 
 
 def tlimit(arg=None, full=False, last=False):
+    """
 
-    if full:
+    Parameters
+    ----------
+    arg: str or list
+        If arg=='full', revert to the full time range. If arg=='last', revert to the previous time range.
+        Otherwise, arg should be a list containing a start and stop time.
+    full: bool
+        If True, revert to the full time range. Equivalent to tlimit('full').
+    last: bool:
+        If True, revert to the previous time range. Equivalent to tlimit('last').
+
+    Returns
+    -------
+        None
+
+    Examples
+    --------
+    >>> import pyspedas
+    >>> pyspedas.tlimit(['2023/03/24/', '2023/03/25'])
+
+    """
+
+    if full or (isinstance(arg,str) and arg == 'full'):
         if pytplot.tplot_opt_glob.get('x_range') is not None:
             del pytplot.tplot_opt_glob['x_range']
-        return
-
-    if last:
+    elif last or (isinstance(arg,str) and arg == 'last'):
         pytplot.tplot_opt_glob['x_range'] = pytplot.tplot_opt_glob['x_range_last']
-        return
-
-    if arg == 'last':
-        xlast = pytplot.lim_info['xlast']
-        pytplot.lim_info['xlast'] = pytplot.tplot_opt_glob['x_range']
-        pytplot.tplot_opt_glob['x_range'] = xlast
-    elif arg == 'full':
-        pytplot.tplot_opt_glob['x_range'] = pytplot.lim_info['xfull']
-    elif isinstance(arg, list):
+    else:
         minn = arg[0]
         maxx = arg[1]
         xlim(minn, maxx)
