@@ -1,5 +1,7 @@
 import numpy as np
+import logging
 import pytplot
+from pytplot import data_exists
 from scipy import signal
 
 
@@ -11,62 +13,77 @@ from scipy import signal
 # Interestingly enough, the output is the same if units of seconds are used in the periodogram instead of Hertz.
 # Perhaps they calculated it differently?
 
-def pwr_spec(tvar, nbp=256, nsp=128, name=None):
+
+def pwr_spec(tvar, nbp=256, nsp=128, newname=None):
     """
     Calculates the power spectrum of a line, and adds a tplot variable for this new spectrogram
 
-    Parameters:
+    Parameters
+    ----------
         tvar : str
             Name of tvar to use
         nbp : int, optional
             The number of points to use when calculating the FFT
         nsp : int, optional
             The number of points to shift over to calculate the next FFT
-        name : str, optional
+        newname : str, optional
             The name of the new tplot variable created,
 
-    Returns:
+    Returns
+    -------
         None
 
-    Examples:
-        >>> pytplot.cdf_to_tplot("/path/to/pytplot/testfiles/mvn_euv_l2_bands_20170619_v09_r03.cdf")
-        >>> pytplot.tplot_math.split_vec('data')
-        >>> pytplot.pwr_spec('data_0')
-        >>> pytplot.tplot('data_0_pwrspec')
+    Examples
+    --------
+        >>> import pyspedas
+        >>> import math
+        >>> time = [pyspedas.time_float("2020-01-01") + i for i in range(10000)]
+        >>> quantity = [math.sin(i) for i in range(10000)]
+        >>> pyspedas.store_data("dp", data={"x": time, "y": quantity})
+        >>> pyspedas.pwr_spec("dp", newname="dp_pwrspec")
+        >>> pyspedas.tplot("dp_pwrspec")
     """
 
-    x, y = pytplot.get_data(tvar)
+    if not data_exists(tvar):
+        logging.error("Input variable %s does not exist", tvar)
+        return
+
+    d = pytplot.get_data(tvar)
+    x, y = d[0], d[1]
 
     if len(y.shape) > 1:
-        print("Can only perform action for a single line")
+        logging.warning(
+            "Cannot create pwr_spec for variable %s, must be a single line", tvar
+        )
 
     l = len(x)
     x_new = []
     f_new = []
     pxx_new = []
-    shift_lsp = np.arange(0, l-1, nsp)
+    shift_lsp = np.arange(0, l - 1, nsp)
     for i in shift_lsp:
-
-        x_n = x[i:i+nbp]
-        y_n = y[i:i+nbp]
+        x_n = x[i : i + nbp]
+        y_n = y[i : i + nbp]
         if len(x_n) < nbp:
             continue
 
         median_diff_between_points = np.median(np.diff(x_n))
-        w = signal.get_window("hanning", nbp)
-        f,pxx = signal.periodogram(y_n, fs=(1/median_diff_between_points), window=w, detrend='linear')
+        w = signal.get_window("hamming", nbp)
+        f, pxx = signal.periodogram(
+            y_n, fs=(1 / median_diff_between_points), window=w, detrend="linear"
+        )
         f = f[1:-1]
         pxx = pxx[1:-1]
         x_new.append((x_n[-1] + x_n[0]) / 2)
         f_new.append(f)
         pxx_new.append(pxx)
 
-    if name is None:
-        name = tvar + "_pwrspec"
+    if newname is None:
+        newname = tvar + "_pwrspec"
 
-    pytplot.store_data(name, data={'x': x_new, 'y': pxx_new, 'v': f_new})
-    pytplot.options(name, 'spec', 1)
-    pytplot.options(name, 'zlog', 1)
-    pytplot.options(name, 'ylog', 1)
+    pytplot.store_data(newname, data={"x": x_new, "y": pxx_new, "v": f_new})
+    pytplot.options(newname, "spec", 1)
+    pytplot.options(newname, "zlog", 1)
+    pytplot.options(newname, "ylog", 1)
 
     return
