@@ -11,19 +11,22 @@ def tplot_rename(old_name, new_name):
     """
     This function will rename tplot variables that are already stored in memory.  
     
-    Parameters:
+    Parameters
+    ----------
         old_name : str 
             Old name of the Tplot Variable
         new_name : str
             New name of the Tplot Variable
          
-    Returns:
+    Returns
+    -------
         None
         
-    Examples:
+    Examples
+    --------
         >>> # Rename Variable 1 to Variable 2
-        >>> import pytplot
-        >>> pytplot.tplot_rename("Variable1", "Variable2")
+        >>> import pyspedas
+        >>> pyspedas.tplot_rename("Variable1", "Variable2")
 
     """
 
@@ -39,7 +42,19 @@ def tplot_rename(old_name, new_name):
         logging.info("The name %s is currently not in pytplot", old_name)
         return
 
-    #remake dictionary with new name in old name's slot
+    # remake dictionary with new name in old name's slot
+
+    # Why not just delete/reinsert the variable being renamed?  Doing it this way
+    # preserves the ordering of variables in the dictionary.  This matches the IDL
+    # behavior, where if 'tha_fit' is the first variable in the list, with index 0,
+    # tplot_rename,'tha_fit', 'tha_fit_rename'
+    # keeps 'tha_fit_rename' at position 0.
+    # No arrays are being copied here, only references, so it's not as inefficient as
+    # it might look.
+    # If the variable being renamed is part of a pseudovariable, you'll end up
+    # with a dangling reference to the old name.  This also matches the IDL behavior,
+    # but should it?   JWL 2024/07/31
+
     d = pytplot.data_quants
     d2 = OrderedDict([(new_name, v) if k == old_name else (k, v) for k, v in d.items()])
     new_data_quants = d2
