@@ -2,37 +2,36 @@
 # Released under the MIT license.
 # This software was developed at the University of Colorado's Laboratory for Atmospheric and Space Physics.
 # Verify current version before use at: https://github.com/MAVENSDC/PyTplot
-
+import logging
 import pytplot
 
 def ylim(name, min, max):
     """
     This function will set the y axis range displayed for a specific tplot variable.
     
-    Parameters:
-        name : str
-            The name of the tplot variable that you wish to set y limits for.  
+    Parameters
+    ----------
+        name : str, int, list of str, list of int
+            The names, indices, or wildcard patterns of the tplot variable that you wish to set y limits for.
         min : flt
             The start of the y axis.
         max : flt
             The end of the y axis.   
             
-    Returns:
+    Returns
+    -------
         None
     
-    Examples:
+    Examples
+    --------
         >>> # Change the y range of Variable1 
-        >>> import pytplot
+        >>> import pyspedas
         >>> x_data = [1,2,3,4,5]
         >>> y_data = [1,2,3,4,5]
-        >>> pytplot.store_data("Variable1", data={'x':x_data, 'y':y_data})
-        >>> pytplot.ylim('Variable1', 2, 4)
+        >>> pyspedas.store_data("Variable1", data={'x':x_data, 'y':y_data})
+        >>> pyspedas.ylim('Variable1', 2, 4)
 
     """
-    if name not in pytplot.data_quants.keys():
-        logging.info("The name %s is currently not in pytplot.",name)
-        return
 
-    pytplot.data_quants[name].attrs['plot_options']['yaxis_opt']['y_range'] = [min, max]
-    
+    pytplot.options(name,'y_range',[min, max])
     return
\ No newline at end of file
