@@ -12,31 +12,29 @@ def zlim(name, min, max):
     This is only used for spec plots, where the z axis represents the magnitude of the values
     in each bin.  
     
-    Parameters:
-        name : str
-            The name of the tplot variable that you wish to set z limits for.  
+    Parameters
+    ----------
+        name : str, int, list of str, list of int
+            The names, indices, or wildcard patterns of the tplot variable that you wish to set z limits for.
         min : flt
             The start of the z axis.
         max : flt
             The end of the z axis.   
             
-    Returns:
+    Returns
+    -------
         None
     
-    Examples:
+    Examples
+    --------
         >>> # Change the z range of Variable1 
-        >>> import pytplot
+        >>> import pyspedas
         >>> x_data = [1,2,3]
         >>> y_data = [ [1,2,3] , [4,5,6], [7,8,9] ]
         >>> v_data = [1,2,3]
-        >>> pytplot.store_data("Variable3", data={'x':x_data, 'y':y_data, 'v':v_data})
-        >>> pytplot.zlim('Variable1', 2, 3)
+        >>> pyspedas.store_data("Variable3", data={'x':x_data, 'y':y_data, 'v':v_data})
+        >>> pyspedas.zlim('Variable1', 2, 3)
 
     """
-    if name not in pytplot.data_quants.keys():
-        logging.info("The name %s is currently not in pytplot.", name)
-        return
-
-    pytplot.data_quants[name].attrs['plot_options']['zaxis_opt']['z_range'] = [min, max]
-    
+    pytplot.options(name,'z_range',[min,max])
     return
\ No newline at end of file
